# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Module-ExtractUse
Version:	0.345
Release:	5.%{__distinit}%{__distvers}
Summary:	Find out which modules are used
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Module-ExtractUse
Source0:	https://cpan.metacpan.org/modules/by-module/Module/Module-ExtractUse-%{version}.tar.gz
Patch0:		Module-ExtractUse-0.345-CleanBuild.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Module::Build) >= 0.37
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Parse::RecDescent) >= 1.967009
BuildRequires:	perl(Pod::Strip)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Test::Deep)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::NoWarnings)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.00
BuildRequires:	perl(UNIVERSAL::require)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Module::ExtractUse is basically a Parse::RecDescent grammar to parse Perl
code. It tries very hard to find all modules (whether pragmas, Core, or
from CPAN) used by the parsed code.

%prep
%setup -q -n Module-ExtractUse-%{version}

# Clean up build process
%patch -P 0

%build
perl Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} -c %{buildroot}

%check
./Build test
./Build test --test_files="xt/*.t"

%files
%license LICENSE
%doc Changes README example/
%{perl_vendorlib}/Module/
%{_mandir}/man3/Module::ExtractUse.3*
%{_mandir}/man3/Module::ExtractUse::Grammar.3*

%changelog
* Fri Jun 14 2024 Paul Howarth <paul@city-fan.org> - 0.345-5
- Avoid use of deprecated patch syntax

* Tue Jan 17 2023 Paul Howarth <paul@city-fan.org> - 0.345-1
- Update to 0.345
  - Auto generate meta_yml_has_provides experimental Kwalitee
- Use SPDX-format license tag

* Mon Sep  6 2021 Paul Howarth <paul@city-fan.org> - 0.344-1
- Update to 0.344
  - Fixed some spelling errors in the Pod
- Use %%license unconditionally
- Fix dist tags for Alma and Rocky Linux

* Wed Jun  5 2019 Paul Howarth <paul@city-fan.org> - 0.343-3
- Perl 5.30 rebuild

* Thu Oct 18 2018 Paul Howarth <paul@city-fan.org> - 0.343-1
- Update to 0.343
  - Mention Perl::PrereqScanner modules family
- Switch upstream from search.cpan.org to metacpan.org

* Tue Jan 23 2018 Paul Howarth <paul@city-fan.org> - 0.342-1
- Update to 0.342
  - Escape left (and right) braces to silence deprecation warnings
    (CPAN RT#124146)
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
- Update cleanbuild patch (version number change only)

* Tue Sep  6 2016 Paul Howarth <paul@city-fan.org> - 0.341-3
- BR: perl-generators where available

* Sun Jan 31 2016 Paul Howarth <paul@city-fan.org> - 0.341-1
- Update to 0.341
  - load_first_existing_class() is now working
  - Class::Load::load_class(), try_load_class() and load_optional_class() are
    working
  - Detect uses of Module::Runtime
  - Include extractuse as provided by Jonathan Yu in example/
  - Linkify POD modules, mention Module::Extract::Use to resolve CPAN RT#45571
  - Fix 20_parse_self.t; version.pm is no longer used
- Classify buildreqs by usage
- Update cleanbuild patch

* Wed Sep 10 2014 Paul Howarth <paul@city-fan.org> - 0.33-3
- Perl 5.20 rebuild

* Sat Apr 12 2014 Paul Howarth <paul@city-fan.org> - 0.33-1
- Update to 0.33
  - Added base() handling to no
  - Support 'no MODULE' etc. (CPAN RT#94305)
  - Typo fix
  - Ignore __DATA|END__ sections (CPAN RT#88969)
  - Ignore use/require method calls
- Update cleanbuild patch (version number change only)
- Drop %%defattr, redundant since rpm 4.4

* Wed Sep  4 2013 Paul Howarth <paul@city-fan.org> - 0.32-1
- Update to 0.32
  - Don't include cached results
  - Fix handling module beginning with v and pragma with version
  - Recognize "use parent"
- Update cleanbuild patch (version number change only)

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 0.31-2
- Perl 5.18 rebuild

* Fri May 31 2013 Paul Howarth <paul@city-fan.org> - 0.31-1
- Update to 0.31
  - Support use Foo::Bar (); etc. (CPAN RT#50723)
  - "use" after statement with trailing comment was ignored (CPAN RT#71761)
  - Fixed the Pod::Simple encoding issue
  - Fix incorrect regexp (ref gh-5)
  - Avoid regex features introduced only in later perl (close gh-5)
  - Use plan() instead of done_testing() (ref gh-5)
  - Add support for bareword leading hyphyen, in-place arrayref and hashref
  - Proper version number for older releases in Changes file
- Drop patches included in new upstream release
- Update cleanbuild patch (version number change only)

* Thu Apr 18 2013 Paul Howarth <paul@city-fan.org> - 0.30-1
- Update to 0.30
  - Add accessors and tests for _in_eval/_out_of_eval
  - Reworked 80_failing.t to TODO tests
  - Added more require-in-string corner test cases
  - Fix the case for eval["']expr["'] and add regression tests
- Update cleanbuild patch (version number change only)
- Include fixes from upstream to support Test::More < 0.88 and perl < 5.10.0
  (https://github.com/domm/Module-ExtractUse/pull/8)

* Mon Feb 25 2013 Paul Howarth <paul@city-fan.org> - 0.29-1
- Update to 0.29
  - Fixed regex to filter use/require (CPAN RT#83569)

* Tue Aug 21 2012 Paul Howarth <paul@city-fan.org> - 0.28-1
- Update to 0.28
  - Whitespace in use base is valid
- Update build patch

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 0.27-3
- Perl 5.16 rebuild

* Thu May 31 2012 Paul Howarth <paul@city-fan.org> - 0.27-2
- Clean up build process to use PL_files
- Bump Module::Build version requirement to 0.37 in readiness for version
  clean-up in Fedora 18

* Fri Mar 23 2012 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27
  - Removed Test::NoWarnings from a t/23_universal_require.t because it upsets
    the (manual) plan if the tests are skipped

* Thu Mar 22 2012 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
  - Autogenerate the grammar during ./Build (CPAN RT#74879)
  - Added $VERSION to into Module::ExtractUse::Grammar (CPAN RT#75342)
  - Require at least version 1.967009 of Parse::RecDescent (CPAN RT#75130)
  - Fix typos (CPAN RT#75115)
  - Switched to Dist::Zilla
- Drop grammar recompilation, no longer needed
- BR: perl(Test::More)
- Bump perl(Module::Build) version requirement to 0.3601
- Bump perl(Parse::RecDescent) version requirement to 1.967009
- Drop perl(Pod::Strip) and perl(Test::Deep) version requirements
- Package manpage for Module::ExtractUse::Grammar

* Fri Mar 16 2012 Paul Howarth <paul@city-fan.org> - 0.24-3
- Recompile the grammar to work with Parse::RecDescent ≥ 1.967009
  (CPAN RT#74879)

* Tue Mar  6 2012 Paul Howarth <paul@city-fan.org> - 0.24-2
- BR: perl(Carp) and perl(version)
- Don't need to remove empty directories from buildroot
- Drop compatibility with distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use Test::Deep unconditionally
  - Don't need to run tests with LC_ALL=C

* Sun Feb 12 2012 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24
  - Regenerated Grammar to work with new Parse::RecDescent
- Drop manual grammar recompilation, no longer needed
- Don't package TODO, no longer included in upstream release

* Thu Feb  2 2012 Paul Howarth <paul@city-fan.org> - 0.23-11
- Recompile the grammar to work with Parse::RecDescent ≥ 1.967
  (CPAN RT#74608)

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 0.23-9
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Mar 17 2011 Paul Howarth <paul@city-fan.org> - 0.23-8
- Import from Fedora

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.23-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec 20 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.23-6
- Rebuild to fix problems with vendorarch/lib (#661697)

* Mon May 03 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.23-5
- Mass rebuild with perl-5.12.0 

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.23-4
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.23-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.23-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Sep  5 2008 Daniel P. Berrange <berrange@redhat.com> - 0.23-1
- Update to 0.23 release

* Fri Feb  8 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.22-2
- Rebuild for new perl

* Fri Dec 21 2007 Daniel P. Berrange <berrange@redhat.com> - 0.22-1
- Specfile autogenerated by cpanspec 1.73
